Return catalog row orders for all supported catalog types
Source:R/catalog_row_order.R
catalog_row_order.RdReturns a named list containing the canonical row ordering for each catalog type. These are used for validation and ordering of mutation catalogs.
Value
A named list with elements: SBS96, SBS192, SBS288, SBS1536, DBS78, DBS136, DBS144, ID (83-category COSMIC indels), ID166, ID89, ID476.