Return catalog row orders for all supported catalog types
Source:R/catalog_row_order.R
catalog_row_order.RdReturns a named list containing the canonical row ordering for each catalog type. These are used for validation and ordering of mutation catalogs. The result is cached after the first call.